@@ -1,7 +1,7 @@
 import pytest
 import numpy as np
 from spotPython.utils.init import fun_control_init
-from spotPython.light.netlightregression import NetLightRegression
+from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 from spotPython.hyperparameters.values import add_core_model_to_fun_control
 from spotPython.fun.hyperlight import HyperLight
